-- 临时背包
Lua_TreasurePackWindow = class("Lua_TreasurePackWindow", Lua_ThirdSizeWindow)
function Lua_TreasurePackWindow:ctor()
	self:superCall("ctor", true, 3500, true, LanUtil.getValue(121416));

	self.windowName = "Lua_TreasurePackWindow";
	self.skinName = "TreasurePackWindow_skin";
	self.w = 600;
	self.h = 499;
	self.isClickClose = true;
end

function Lua_TreasurePackWindow:buildShowItem()
	self:superCall("buildShowItem");
    
	self.descTxt.text = LanUtil.getValue(121414);

	local onePageCount = DataCenter.treasureUtil:getStoreSize();
	local horizontalNum = 7;
	local verticalNum = 4;
	self.pageLen = math.ceil(onePageCount / (horizontalNum * verticalNum));

	local pageIcon;
	local perWidth = 22;
	self.pageTipList = Array();
	for i = 1, self.pageLen do
		pageIcon = UICreate.createUIAtlasImage(self.content, "common_atlas_1", "ui_common_b_1", 0, 0, 0, 0);
		pageIcon.name = tostring(i);
		pageIcon:setDepth(5);
		pageIcon:setLocation(-perWidth * self.pageLen / 2 + perWidth * (i - 1) + perWidth / 2, -145, 0);
		pageIcon:addClickFuntion(self, self.onPageClick);
		self.pageTipList:add(pageIcon);
	end

	self.dragList = Lua_DragList.new(self.content, 2, Vector4(0, 0, 553, 302));
	self.dragList:setListCell(Lua_TreasurePackItem, 302, 553, 1000);
	self.dragList:setCellScaleChange(true, 1, 1, 553, self, self.onPageCallBack);
	self.dragList:setLocation(0, 30, 0);
	self:updateData();
	self.dragList:moveToIndex(1, true);

	self.sortBtn:addClickFuntion(self, self.onSortBtnClick);
	self.pickUpBtn:addClickFuntion(self, self.onPickUpBtnClick);

	self:addLuaEvent("PACK_UPDATE", self, self.onPackDataUpdate);
end

-- 背包更新
function Lua_TreasurePackWindow:onPackDataUpdate(packType)
	if packType == Lua_PackData.TREASURE_SOTRE then -- 临时仓库更新
		self:updateData();
	end
end

function Lua_TreasurePackWindow:onSortBtnClick(go)
	if self.clickTime ~= nil and getTime() - self.clickTime < 0.3 then
		OperateAlert.show(LanUtil.getValue(121419));
		return;
	end
	self.clickTime = getTime();

	Lua_ProxyManager.getProxy("Lua_TreasureProxy"):sTreasureStoreSort();
end

function Lua_TreasurePackWindow:onPickUpBtnClick(go)
	if self.clickTime ~= nil and getTime() - self.clickTime < 0.3 then
		OperateAlert.show(LanUtil.getValue(121419));
		return;
	end
	self.clickTime = getTime();

	local bagData = DataCenter.packData:getBagType(Lua_PackData.TREASURE_SOTRE);
	local arr = bagData:getBagAllData();
	if arr:getSize() <= 0 then
		OperateAlert.show(LanUtil.getValue(121428));
		return;
	end

	-- 一键取出
	Lua_ProxyManager.getProxy("Lua_TreasureProxy"):sTreasureStorePickUp(1, 0);
end

function Lua_TreasurePackWindow:onPageClick(go)
	self.dragList:moveToIndex(tonumber(go.name));
end

function Lua_TreasurePackWindow:onPageCallBack(val)
	local len = self.pageTipList:getSize();
	for i = 1, len do
		if i == val then
			self.pageTipList[i]:setAltas("common_atlas_1", "ui_common_b_2");
		else
			self.pageTipList[i]:setAltas("common_atlas_1", "ui_common_b_1");
		end
	end
end

function Lua_TreasurePackWindow:updateData()
	local arr = Array();
	for i = 1, self.pageLen do
		arr:add({page = i, startIndex = (i - 1) * 28});
	end
	self.dragList:setLuaArrayData(arr);	
end

function Lua_TreasurePackWindow:dispose()
	if self.dragList ~= nil then
		self.dragList:dispose()
		self.dragList = nil;
	end
	if self.pageTipList ~= nil then
		for i = 1, self.pageTipList:getSize() do
			self.pageTipList[i]:dispose();
		end
		self.pageTipList:clear();
		self.pageTipList = nil;
	end
	-- Lua_ProxyManager.getProxy("Lua_TreasureProxy"):sTreasureStoreSort();

	self:superCall("dispose");
end





--------------------------------------------------





Lua_TreasurePackItem = class("Lua_TreasurePackItem", Lua_ListCell);
function Lua_TreasurePackItem:buildShowItem()
	self:superCall("buildShowItem");

	self.lastClickIndex = -1;
	self.lastClickTime = 0;

	local cell;
	local perWidth = 80;
	local perHeight = 80;
	local startX = -perWidth * (7 - 1) / 2;
	local startY = perHeight * (4 - 1) / 2;
	self.cells = Array();
	for j = 1, 4 do
		for i = 1, 7 do
			cell = Lua_ToolImage.new(self.content);
			cell.content.name = "cell"..(i + (j - 1) * 7);
			cell.defaultRoundEffect = true;
			cell:setDepth(4);
			cell:setScale(0.8, 0.8);
			cell:setCanClick(false);
			cell:setLocation(startX + (i - 1) * perWidth, startY - (j - 1) * perHeight, 0);
			self.cells:add(cell);
		end
	end

	local itemWidth = self.cells[1].item_bg.width * 0.8 / 2;
	local itemHeight = self.cells[1].item_bg.height * 0.8 / 2;
	self.cellPosX = Array();
	for i = 1, 7 do
		self.cellPosX:add({startX + (i - 1) * perWidth - itemWidth, startX + (i - 1) * perWidth + itemWidth});
	end

	self.cellPosY = Array();
	for i = 1, 4 do
		self.cellPosY:add({startY - (i - 1) * perHeight - itemHeight, startY - (i - 1) * perHeight + itemHeight});
	end
end

function Lua_TreasurePackItem:setData(data)
	if data == nil then
		return;
	end
	self.startIndex = data.startIndex;

	local bagData = DataCenter.packData:getBagType(Lua_PackData.TREASURE_SOTRE);
	local packSize = bagData.packSize == nil and DataCenter.treasureUtil:getStoreSize() or bagData.packSize;
	local curIndex;
	for i = 1, self.cells:getSize() do
		curIndex = data.startIndex + i - 1;
		if curIndex >= packSize then
			self.cells[i].data = nil;
			self.cells[i]:setEnable(false);
		else
			self.cells[i].data = bagData:getItemByIndex(curIndex);
			self.cells[i]:setEnable(true);
		end
	end
end

function Lua_TreasurePackItem:checkOutBound(showRect)
	for i = 1, self.cells:getSize() do
		if self.cells[i].data ~= nil then
			local rect = Lua_Rectangle.new(self.itemX + self.cells[i].x - 40, self.itemY + self.cells[i].y - 40, 80, 80);
			self.cells[i]:showRoundEffectView(showRect:containeRect(rect));
		end
	end
end

function Lua_TreasurePackItem:onPlayerSoundClick()
	local inputPos = Vector3(UnityEngine.Input.mousePosition.x, UnityEngine.Input.mousePosition.y, 0);
	local screenpos = UICamera.mainCamera:ScreenToWorldPoint(inputPos);
	local mousePosition = self.content.transform:InverseTransformPoint(screenpos);
	local cx = 0;
	for i = 1, self.cellPosX:getSize() do
		if self.cellPosX[i][1] <= mousePosition.x and self.cellPosX[i][2] >= mousePosition.x then
			cx = i;
			break;
		end
	end

	if cx == 0 then
		return;
	end

	local cy = 0;
	for i = 1, self.cellPosY:getSize() do
		if self.cellPosY[i][1] <= mousePosition.y and self.cellPosY[i][2] >= mousePosition.y then
			cy = i;
			break;
		end
	end
	
	if cy == 0 then
		return;
	end

	self.clickIndex = cx + (cy - 1) * 7;
	if self.lastClickIndex ~= self.clickIndex or getTime() - self.lastClickTime > 0.3 then
		self.lastClickTime = getTime();
		self.lastClickIndex = self.clickIndex;
		Lua_CommonUtil.delayCall(0.3, self, self.onSingleClick);
	else
		Lua_CommonUtil.removeTimer(self, self.onSingleClick);
		self:onDoubleClick();
		self.lastClickTime = -1;
	end
end

function Lua_TreasurePackItem:onDoubleClick()
	local tvo = self.cells[self.clickIndex].data;
	if tvo == nil then
		return;
	end

	-- 取出
	Lua_ProxyManager.getProxy("Lua_TreasureProxy"):sTreasureStorePickUp(0, tvo.index);
end

function Lua_TreasurePackItem:onSingleClick()
	local tvo = self.cells[self.clickIndex].data;
	if tvo == nil then
		return;
	end

	-- 展示tips
	Lua_PackUtil.showItemInfo(tvo);
end

function Lua_TreasurePackItem:dispose()
	Lua_CommonUtil.removeTimer(self, self.onSingleClick);
	self:superCall("dispose");
end