Lua_RunesTreasurePanel = class("Lua_RunesTreasurePanel", Lua_DisplayObject);
function Lua_RunesTreasurePanel:ctor(p)
	self:superCall("ctor", p, "TreasureRunes_skin");
end

function Lua_RunesTreasurePanel:buildShowItem()
	self:superCall("buildShowItem");

	self.descTxt.text = LanUtil.getValue(121407);
	self.oneBtn.label = LanUtil.getValue(121442);
	self.tenBtn.label = LanUtil.getValue(121443);

	-- 已解锁类型
	self.openList = Lua_DragList.new(self.content, 1, Vector4(0, 0, 330, 400));
	self.openList:setLocation(438, 5, 0);
	self.openList:setListCell(Lua_TreasureRuneOpenShowItem, 130, 110, 3);
	self.openList:setLuaArrayData(DataCenter.treasureData:getRuneOpenTypeShow(), false);

	local costId = DataCenter.treasureUtil.runeDrawCostId;
	if costId ~= nil then
		self.costVo = Lua_ToolVo.new(costId);
		self.icon_left:setAltas(self.costVo.atlas, self.costVo.referenceId);
		self.icon_right:setAltas(self.costVo.atlas, self.costVo.referenceId)
	end

	local tvo;
	local data =  DataCenter.treasureUtil.runeRewadrShow;
	for i,v in ipairs(data) do
		tvo =  Lua_ToolVo.new(v)
		self.item = Lua_ToolImage.new(self.content);
		self.item:setDepth(1);
		self.item:setLocation(-242 + (i - 1) * 107, 88, 0);
		self.item.data = tvo;

		self.btnTxt = UICreate.createLabel(self.content, "", 0, 0, 200, 30, 22);
		self.btnTxt.pivot = UIWidget.Pivot.Center;
		self.btnTxt.text = tvo.colorName;
		self.btnTxt:setDepth(1);
		self.btnTxt:setLocation(-242 + (i - 1) * 108, 26, 0);
	end

	self.helpImg:addClickFuntion(self, self.onHelpClick);
	self.oneBtn:addClickFuntion(self, self.onOneBtnClick);
	self.tenBtn:addClickFuntion(self, self.onTenBtnClick);
	self.packBtn:addClickFuntion(self, self.onPackBtnClick);
	self.exchangeBtn:addClickFuntion(self, self.onExchangeBtnClick);
	self.icon_left:addClickFuntion(self, self.onCostIconClick);
	self.icon_right:addClickFuntion(self, self.onCostIconClick);

	Lua_MsgUtil.callFunc("TREASURE_REDDOT_POS", 10079);

	self:updateSprUI();
	self:updateCost();
	self:onTreasurePanelInfo();

	self:addLuaEvent("rTreasurePanelInfo", self, self.onTreasurePanelInfo);
	self:addLuaEvent("rTreasureRunesDraw", self, self.onTreasureRunesDraw);
	self:addLuaEvent("PACK_UPDATE", self, self.onPackDataUpdate);
	self:addLuaEvent("rOpenRunePanelInfo", self, self.updateSprUI);-- 更新UI
end

function Lua_RunesTreasurePanel:updateSprUI()
	if DataCenter.runeData.isOpenCompound then
		self.middleTipsTxt.text = LanUtil.getValue(121450);
		self.runeSp:setEnable(true);
		self.runeSp:setLocation(61, -77);
	else
		self.middleTipsTxt.text = LanUtil.getValue(121449);
		self.runeSp:setEnable(false);
	end
end

-- 更新消耗
function Lua_RunesTreasurePanel:updateCost()
	local costId = DataCenter.treasureUtil.runeDrawCostId;
	local ownNum = DataCenter.packData:getBagType(Lua_PackData.BAG_PACK):getItemNum(costId);
	local costOneNum = DataCenter.treasureUtil.runeDrawOneCostNum;
	local str;
	if ownNum >= costOneNum then
		self.bEnoughOneCost = true;
		str = "["..Lua_ColorDefine.GREEN_STR.."]"..ownNum.."/"..costOneNum.."[-]";
	else
		self.bEnoughOneCost = false;
		str = "["..Lua_ColorDefine.RED_STR.."]"..ownNum.."/"..costOneNum.."[-]";
	end
	self:updateOneBtnRedDot();
	self.costNum_one.text = LanUtil.formateStr(LanUtil.getValue(121401), str);

	local costTenNum = DataCenter.treasureUtil.runeDrawTenCostNum;
	if ownNum >= costTenNum then
		self.bEnoughTenCost = true;
		str = "["..Lua_ColorDefine.GREEN_STR.."]"..ownNum.."/"..costTenNum.."[-]";
	else
		self.bEnoughTenCost = false;
		str = "["..Lua_ColorDefine.RED_STR.."]"..ownNum.."/"..costTenNum.."[-]";
	end
	self.tenBtnRedDot:setEnable(self.bEnoughTenCost);
	self.costNum_ten.text = LanUtil.formateStr(LanUtil.getValue(121401), str);

	self:updateCostIconPos();
end

function Lua_RunesTreasurePanel:updateOneBtnRedDot()
	self.oneBtnRedDot:setEnable(self.bEnoughOneCost or DataCenter.treasureData.runeFreeReduiseTime <= 0);
end

function Lua_RunesTreasurePanel:updateCostIconPos()
	local oneCostSize = self.costNum_one:lastPrintedSize(self.costNum_one.text);
	local tenCostSize = self.costNum_ten:lastPrintedSize(self.costNum_ten.text);
	self.icon_left:setLocation(oneCostSize.x / 2 - 24, 0);
	self.icon_right:setLocation(tenCostSize.x / 2 - 24, 0);
end

-- 面板信息
function Lua_RunesTreasurePanel:onTreasurePanelInfo(list)
	self:updateChips();
	self:updateFreeTime();
end

-- 更新碎片
function Lua_RunesTreasurePanel:updateChips(num)
	if num == nil then
		num = DataCenter.treasureData.runeChipsNum;
	end
	self.chipNumTxt.text = LanUtil.formateStr(LanUtil.getValue(121420), tostring(num));
end

-- 更新免费的时间
function Lua_RunesTreasurePanel:updateFreeTime()
	self:updateOneBtnRedDot();

	local num = DataCenter.treasureData.runeFreeReduiseTime;
	self.freeTimeTxt.text = LanUtil.formateStr(LanUtil.getValue(121405), TimeTransform.getInstance():transSeconds6(num, true, true));
	if num > 0 then
		self:startTimer();
	else
		self.freeTimeTxt.text = LanUtil.getValue(121421);
		self:endTimer();
	end
end

function Lua_RunesTreasurePanel:startTimer()
	if self.bRegisterTimer ~= true then
		self.bRegisterTimer = true;
		Lua_CommonUtil.addTimer("Lua_RunesTreasurePanel", 1, self, self.updateRunesFreeTime);
	end
end

function Lua_RunesTreasurePanel:updateRunesFreeTime()
	local num = DataCenter.treasureData.runeFreeReduiseTime;
	self.freeTimeTxt.text = LanUtil.formateStr(LanUtil.getValue(121405), TimeTransform.getInstance():transSeconds6(num, true, true));
	if num <= 0 then
		self:updateOneBtnRedDot();

		self.freeTimeTxt.text = LanUtil.getValue(121421);
		self:endTimer();
	end
end

function Lua_RunesTreasurePanel:endTimer()
	if self.bRegisterTimer == true then
		self.bRegisterTimer = false;
		Lua_CommonUtil.removeTimer(self, self.updateRunesFreeTime);
	end
end

-- 抽奖返回
function Lua_RunesTreasurePanel:onTreasureRunesDraw(msg)
	self:updateChips(msg.frag_count); -- 灵纹碎片
	self:updateFreeTime();
end

-- 背包更新
function Lua_RunesTreasurePanel:onPackDataUpdate(packType)
	if packType == Lua_PackData.BAG_PACK then
		self:updateCost();
	end
end

function Lua_RunesTreasurePanel:onHelpClick(go)
	Lua_WindowUtil.openWin("Lua_RuleTipWindow", WinParam.ACTION_OPEN, LanUtil.getValue(121430));
end

function Lua_RunesTreasurePanel:onOneBtnClick(go)
	if self.clickTime ~= nil and getTime() - self.clickTime < 0.3 then
		OperateAlert.show(LanUtil.getValue(121419));
		return;
	end
	self.clickTime = getTime();

	local num = DataCenter.treasureData.runeFreeReduiseTime;
	if num <= 0 then -- 免费
		Lua_ProxyManager.getProxy("Lua_TreasureProxy"):sTreasureRunesDraw(0);
		return;
	end

	if self.bEnoughOneCost == false then
		if self.costVo ~= nil then
			local ownNum = DataCenter.packData:getBagType(Lua_PackData.BAG_PACK):getItemNum(DataCenter.treasureUtil.runeDrawCostId);
			local costNum = DataCenter.treasureUtil.runeDrawOneCostNum;
			local needBuyNum = costNum - ownNum;
			self.costGoldNum = self.costVo.goldPrice * needBuyNum;
			local str;
			if DataCenter.moneyData:getMoney(Lua_MoneyData.GOLD) < self.costGoldNum then
				str = "["..Lua_ColorDefine.RED_STR.."]"..self.costGoldNum.."[-]";
				self.bEnoughGold = false;
			else
				str = "["..Lua_ColorDefine.GREEN_STR.."]"..self.costGoldNum.."[-]";
				self.bEnoughGold = true;
			end

			if DataCenter.neverTip:getNeverValue("Lua_RunesTreasurePanel") then
				if self.bEnoughGold == false then
					OperateAlert.show(LanUtil.formateStr(LanUtil.getValue(121427), self.costVo.colorName));
				else
					Lua_ProxyManager.getProxy("Lua_TreasureProxy"):sTreasureRunesDraw(0);
				end
				return;
			end
			Lua_WindowUtil.openWin("Lua_TipsWindow", nil, {owner = self, neverTip = "Lua_RunesTreasurePanel",
				des = LanUtil.formateStr(LanUtil.getValue(121426), self.costVo.colorName, str, tostring(needBuyNum)),
				type = 1, subFun = self.onSureOneFun});
		end
		return;
	end
	Lua_ProxyManager.getProxy("Lua_TreasureProxy"):sTreasureRunesDraw(0);
end

function Lua_RunesTreasurePanel:onSureOneFun()
	if self.bEnoughGold then
		Lua_ProxyManager.getProxy("Lua_TreasureProxy"):sTreasureRunesDraw(0);
	else
		DataCenter.moneyData:isMoneyEnough(Lua_MoneyData.GOLD, self.costGoldNum, true, true);
	end
end

function Lua_RunesTreasurePanel:onTenBtnClick(go)
	if self.clickTime ~= nil and getTime() - self.clickTime < 0.3 then
		OperateAlert.show(LanUtil.getValue(121419));
		return;
	end
	self.clickTime = getTime();

	if self.bEnoughTenCost == false then
		if self.costVo ~= nil then
			local ownNum = DataCenter.packData:getBagType(Lua_PackData.BAG_PACK):getItemNum(DataCenter.treasureUtil.runeDrawCostId);
			local costNum = DataCenter.treasureUtil.runeDrawTenCostNum;
			local needBuyNum = costNum - ownNum;
			self.costGoldNum = self.costVo.goldPrice * needBuyNum;
			local str;
			if DataCenter.moneyData:getMoney(Lua_MoneyData.GOLD) < self.costGoldNum then
				str = "["..Lua_ColorDefine.RED_STR.."]"..self.costGoldNum.."[-]";
				self.bEnoughGold = false;
			else
				str = "["..Lua_ColorDefine.GREEN_STR.."]"..self.costGoldNum.."[-]";
				self.bEnoughGold = true;
			end

			if DataCenter.neverTip:getNeverValue("Lua_RunesTreasurePanel") then
				if self.bEnoughGold == false then
					OperateAlert.show(LanUtil.formateStr(LanUtil.getValue(121427), self.costVo.colorName));
				else
					Lua_ProxyManager.getProxy("Lua_TreasureProxy"):sTreasureRunesDraw(1);
				end
				return;
			end
			Lua_WindowUtil.openWin("Lua_TipsWindow", nil, {owner = self, neverTip = "Lua_RunesTreasurePanel",
				des = LanUtil.formateStr(LanUtil.getValue(121426), self.costVo.colorName, str, tostring(needBuyNum)),
				type = 1, subFun = self.onSureTenFun});
		end
		return;
	end
	Lua_ProxyManager.getProxy("Lua_TreasureProxy"):sTreasureRunesDraw(1);
end

function Lua_RunesTreasurePanel:onSureTenFun()
	if self.bEnoughGold then
		Lua_ProxyManager.getProxy("Lua_TreasureProxy"):sTreasureRunesDraw(1);
	else
		DataCenter.moneyData:isMoneyEnough(Lua_MoneyData.GOLD, self.costGoldNum, true, true);
	end
end

function Lua_RunesTreasurePanel:onPackBtnClick(go)
	Lua_WindowUtil.openWin("Lua_RunePackWindow", WinParam.ACTION_OPEN);
end

function Lua_RunesTreasurePanel:onExchangeBtnClick(go)
	Lua_WindowUtil.openWin("Lua_LifeSoulWindow", WinParam.ACTION_OPEN, {openIdx = 1, nameIndex = 3});
end

function Lua_RunesTreasurePanel:onCostIconClick(go)
	if self.costVo ~= nil then
		Lua_PackUtil.showItemInfo(self.costVo);
	end
end

function Lua_RunesTreasurePanel:dispose()
	if self.openList ~= nil then
		self.openList:dispose();
		self.openList = nil;
	end
	self:endTimer();

	self:superCall("dispose");
end





--------------------------------------------------





Lua_TreasureRuneOpenShowItem = class("Lua_TreasureRuneOpenShowItem", Lua_ListCell);
function Lua_TreasureRuneOpenShowItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_TreasureRuneOpenShowItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon = UICreate.createUIAtlasImage(self.content, nil, nil, 0, 12, 68, 80);
	self.itemIcon:setDefault("item1", "default_item");
	self.itemIcon:setDepth(1);

	self.btnTxt = UICreate.createLabel(self.content, "", 0, -54, 200, 30, 22);
	self.btnTxt.pivot = UIWidget.Pivot.Center;
	self.btnTxt.overflowMethod = UILabel.Overflow.ResizeFreely;
	self.btnTxt:setDepth(2);
end

function Lua_TreasureRuneOpenShowItem:setData(data)
	self._data = data;
	if data == nil then
		return;
	end

	if data.atlas ~= nil and data.referenceId ~= nil then
		self.itemIcon:setAltas(data.atlas, data.referenceId);
	end
	self.btnTxt.text = data.colorName;
end

function Lua_TreasureRuneOpenShowItem:onPlayerSoundClick(go)
	if self._data ~= nil then
		Lua_PackUtil.showItemInfo(self._data);
	end
end

function Lua_TreasureRuneOpenShowItem:dispose()
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	if self.btnTxt ~= nil then
		self.btnTxt:dispose();
		self.btnTxt = nil;
	end
	self._data = nil;

	self:superCall("dispose");
end